@@ -526,11 +526,11 @@ def info(x = 0):
 
     if x == 0:
         print('\n' + __pack.upper() + '\n'
-            '\nver. 2.0.4\n '
+            '\nver. 2.0.5\n '
             f'\nHere the {str(len(funcdict))} functions available in {__pack}\n')
         for i in funcdict.keys():
             print('>>> ' + i)
-        print(f'\nHere the {str(len(classdict))} classes available in {__pack}\n')
+        print(f'\nHere the {str(len(classdict))} class available in {__pack}\n')
         for i in classdict.keys():
             print('>>> ' + i)
         print(f'\nrun {__pack}.info(<func_or_class_name>) to see more detailed informations for that function.')
